@@ -14,5 +14,5 @@ HEADERS = {
 def id_to_level(id: str): return id.count('.')
 
 
-def exec_request(gid: str, **kwargs):
+def get_gadm_data(gid: str, **kwargs):
     return requests.post(f"{API_URL}/{id_to_level(gid)}", json.dumps(kwargs), headers=HEADERS).json() if API_URL else {}
