@@ -2,10 +2,9 @@ from typing import List
 from functools import reduce
 from hestia_earth.schema import SiteSiteType
 
-from hestia_earth.validation.geojson import get_geojson_area
-from hestia_earth.validation.gadm import exec_request
 from .shared import list_has_props, validate_dates, validate_list_dates, validate_list_duplicates, diff_in_years, \
-    validate_list_min_max, validate_region, validate_country
+    validate_list_min_max, validate_region, validate_country, validate_coordinates, need_validate_coordinates, \
+    validate_area, need_validate_area
 
 
 SOIL_TEXTURE_IDS = ['sandContent', 'siltContent', 'clayContent']
@@ -35,7 +34,8 @@ def validate_soilTexture(measurements: List[dict]):
     def validate(values):
         values = list(filter(lambda v: v['term']['@id'] in SOIL_TEXTURE_IDS, values))
         terms = list(map(lambda v: v['term']['@id'], values))
-        return len(set(terms)) != len(SOIL_TEXTURE_IDS) or 99.5 < sum(map(lambda v: v['value'], values)) < 100.5 or {
+        sum_values = sum(map(lambda v: v.get('value', 0), values))
+        return len(set(terms)) != len(SOIL_TEXTURE_IDS) or 99.5 < sum_values < 100.5 or {
             'level': 'error',
             'dataPath': '.measurements',
             'message': 'The sum of Sand, Silt, and Clay content should equal 100% for each soil depth interval.'
@@ -110,38 +110,8 @@ def validate_site_dates(site: dict):
     }
 
 
-def validate_area(site: dict):
-    try:
-        area = get_geojson_area(site.get('boundary'))
-        return area == round(site.get('area'), 1) or {
-            'level': 'error',
-            'dataPath': '.area',
-            'message': f"must be equal to boundary (~{area})"
-        }
-    except KeyError:
-        # if getting the geojson fails, the geojson format is invalid
-        # and the schema validation step will detect it
-        return True
-
-
-def need_validate_coordinates(site: dict):
-    return 'latitude' in site and 'longitude' in site and site.get('siteType') in INLAND_TYPES
-
-
-def validate_coordinates(site: dict):
-    latitude = site.get('latitude')
-    longitude = site.get('longitude')
-    country = site.get('country', {})
-    region = site.get('region')
-    gadm_id = region.get('@id') if region else country.get('@id')
-    id = None if region else gadm_id  # pass in the id for a country for faster results
-    res = exec_request(gadm_id, id=id, latitude=latitude, longitude=longitude)
-    id = res.get('id')
-    return (region and region.get('@id') == id) or (country.get('@id') == id) or {
-        'level': 'error',
-        'dataPath': '.region' if region else '.country',
-        'message': 'does not contain latitude and longitude'
-    }
+def validate_site_coordinates(site: dict):
+    return need_validate_coordinates(site) and site.get('siteType') in INLAND_TYPES
 
 
 def validate_site(site: dict):
@@ -149,8 +119,8 @@ def validate_site(site: dict):
         validate_site_dates(site),
         validate_country(site) if 'country' in site else True,
         validate_region(site) if 'region' in site else True,
-        validate_coordinates(site) if need_validate_coordinates(site) else True,
-        validate_area(site) if 'area' in site and 'boundary' in site else True
+        validate_coordinates(site) if validate_site_coordinates(site) else True,
+        validate_area(site) if need_validate_area(site) else True
     ] + ([
         validate_list_dates(site, 'measurements'),
         validate_list_min_max(site, 'measurements'),
